@@ -22,7 +22,7 @@ our @EXPORT = qw(cetak cetak_r);
 
 # Define Version :
 # ---------------------------------------------------------------- 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 # Create Subroutine for Get OS Server Information :
 # ------------------------------------------------------------------------
@@ -545,14 +545,21 @@ sub cetak {
 
 =cut
 sub cetak_r {
-	# ----------------------------------------------------------------
-	# Define parameter subroutine :
-	# ----------------------------------------------------------------
-	my ($ref) = @_;
     # ----------------------------------------------------------------
-    # Print Dumper :
+    # Check Parameter Subroutine :
     # ----------------------------------------------------------------
-    print Dumper $ref;
+    if (keys(@_) eq 1) {
+        # ----------------------------------------------------------------
+        # Print Dumper :
+        # ----------------------------------------------------------------
+        print Dumper $_[0];
+    }
+    if (keys(@_) > 1) {
+        # ----------------------------------------------------------------
+        # Print Dumper :
+        # ----------------------------------------------------------------
+        print Dumper \@_;
+    }
 }
 # End of Subroutine for Print ref.
 # ===========================================================================================================
